parse_derivative_ticker_msg

Function parse_derivative_ticker_msg 

pub fn parse_derivative_ticker_msg(
    msg: &DerivativeTickerMsg,
    instrument_id: InstrumentId,
) -> Result<Option<FundingRateUpdate>>
Parses a derivative ticker message into a funding rate update.

Errors

Returns an error if timestamp conversion or decimal conversion fails.